==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ABinopBoolExpr.h <==
// public final class soot.jimple.parser.node.ABinopBoolExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bb42b44837212325 soot_jimple_parser_node_ABinopBoolExpr
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 62b466cd5126c2ce soot_jimple_parser_node_PBoolExpr

// header file dependencies
// @dep_header soot_jimple_parser_node_PBoolExpr

#include "soot/jimple/parser/node/PBoolExpr.h"

#ifndef _JC_soot_jimple_parser_node_ABinopBoolExpr_H_
#define _JC_soot_jimple_parser_node_ABinopBoolExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PBinopExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs	_jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs	_jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$refs	_jc_soot_jimple_parser_node_ABinopBoolExpr$refs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs	_jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object	_jc_soot_jimple_parser_node_ABinopBoolExpr$object;

typedef const struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods	_jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtable	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtype	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$_init$b2186e837e010314(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABinopBoolExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);
extern struct _jc_soot_jimple_parser_node_PBinopExpr$object *_jc_soot_jimple_parser_node_ABinopBoolExpr$method$getBinopExpr$064cedbe89393696(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$setBinopExpr$f221fbe5d5c2fb3c(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABinopBoolExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$getBinopExpr$064cedbe89393696;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$setBinopExpr$f221fbe5d5c2fb3c;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*(*getBinopExpr$064cedbe89393696)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setBinopExpr$f221fbe5d5c2fb3c)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBoolExpr$vmethods	soot_jimple_parser_node_PBoolExpr;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods	soot_jimple_parser_node_ABinopBoolExpr;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs {
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*__5fbinopExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$refs {
    _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs	soot_jimple_parser_node_ABinopBoolExpr;
    _jc_soot_jimple_parser_node_PBoolExpr$sub_refs	soot_jimple_parser_node_PBoolExpr;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBoolExpr$sub_nonrefs	soot_jimple_parser_node_PBoolExpr;
    _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs	soot_jimple_parser_node_ABinopBoolExpr;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object {
	_jc_soot_jimple_parser_node_ABinopBoolExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABinopBoolExpr$vtype _jc_soot_jimple_parser_node_ABinopBoolExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABinopBoolExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABinopBoolExpr$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABinopBoolExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ABinopBoolExpr.h <==
// public final class soot.jimple.parser.node.ABinopBoolExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bb42b44837212325 soot_jimple_parser_node_ABinopBoolExpr
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 62b466cd5126c2ce soot_jimple_parser_node_PBoolExpr

// header file dependencies
// @dep_header soot_jimple_parser_node_PBoolExpr

#include "soot/jimple/parser/node/PBoolExpr.h"

#ifndef _JC_soot_jimple_parser_node_ABinopBoolExpr_H_
#define _JC_soot_jimple_parser_node_ABinopBoolExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PBinopExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs	_jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs	_jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$refs	_jc_soot_jimple_parser_node_ABinopBoolExpr$refs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs	_jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object	_jc_soot_jimple_parser_node_ABinopBoolExpr$object;

typedef const struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods	_jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtable	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtable;
typedef const struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtype	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$_init$b2186e837e010314(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ABinopBoolExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PBinopExpr$object *_jc_soot_jimple_parser_node_ABinopBoolExpr$method$getBinopExpr$064cedbe89393696(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ABinopBoolExpr$method$setBinopExpr$f221fbe5d5c2fb3c(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ABinopBoolExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$getBinopExpr$064cedbe89393696;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$setBinopExpr$f221fbe5d5c2fb3c;
extern _jc_method _jc_soot_jimple_parser_node_ABinopBoolExpr$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*(*getBinopExpr$064cedbe89393696)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setBinopExpr$f221fbe5d5c2fb3c)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *, struct _jc_soot_jimple_parser_node_PBinopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBoolExpr$vmethods	soot_jimple_parser_node_PBoolExpr;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$vmethods	soot_jimple_parser_node_ABinopBoolExpr;
};

// Vtype
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs {
	struct _jc_soot_jimple_parser_node_PBinopExpr$object	*__5fbinopExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$refs {
    _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_refs	soot_jimple_parser_node_ABinopBoolExpr;
    _jc_soot_jimple_parser_node_PBoolExpr$sub_refs	soot_jimple_parser_node_PBoolExpr;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBoolExpr$sub_nonrefs	soot_jimple_parser_node_PBoolExpr;
    _jc_soot_jimple_parser_node_ABinopBoolExpr$sub_nonrefs	soot_jimple_parser_node_ABinopBoolExpr;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ABinopBoolExpr$object {
	_jc_soot_jimple_parser_node_ABinopBoolExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$vtype	*vtype;
	_jc_soot_jimple_parser_node_ABinopBoolExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ABinopBoolExpr$vtype _jc_soot_jimple_parser_node_ABinopBoolExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ABinopBoolExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ABinopBoolExpr$class_object;

#endif	/* _JC_soot_jimple_parser_node_ABinopBoolExpr_H_ */
